@@ -17,7 +17,6 @@ THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABI
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 """
-import sys
 import six
 import shutil
 import pickle
@@ -150,7 +149,7 @@ class AbstractBaseApplication(AbstractRunPolicy):
         info("Running version", self.version_string)
         info("Running at", str(datetime.now()))
 
-        self.datasets = DatasetHolder()
+        self.datasets = None
         self.app_paths = self.get_app_paths()
         self.run_policy = self.get_run_policy()
         self.setup()
@@ -435,6 +434,13 @@ class AbstractBaseApplication(AbstractRunPolicy):
         self.cleanup()
         return run_result
 
+    def init_data(self):
+        if not self.datasets:
+            datasets = self.load_data()
+            self.datasets = DatasetHolder()
+            for name, data_source in datasets.items():
+                setattr(self.datasets, name, data_source)
+
     def run_single(self, **kwargs) -> RunResult:
         """ Executes a single run directly (disregarding any __self.run_policy__ that may be in place. """
         prior_args = kwargs
@@ -444,10 +450,7 @@ class AbstractBaseApplication(AbstractRunPolicy):
 
         output_directory = self.output_directory
 
-        datasets = self.load_data()
-        for name, data_source in datasets.items():
-            setattr(self.datasets, name, data_source)
-
+        self.init_data()
         model = self.get_model()
         model = self.train_model(model)
         if model is not None:
@@ -459,7 +462,8 @@ class AbstractBaseApplication(AbstractRunPolicy):
         args_file_path = self.app_paths.get_args_file_path(output_directory)
 
         info("Saving args to", args_file_path)
-        pickle.dump(self.get_params(), open(args_file_path, "wb"), pickle.HIGHEST_PROTOCOL)
+        with open(args_file_path, "wb") as fp:
+            pickle.dump(self.get_params(), fp, pickle.HIGHEST_PROTOCOL)
 
         eval_score, test_score, threshold = None, None, None
         if self.evaluate:
@@ -471,7 +475,11 @@ class AbstractBaseApplication(AbstractRunPolicy):
         MetricDictTools.save_metric_dict(eval_score, self.app_paths.get_eval_score_dict_path(output_directory))
         MetricDictTools.save_metric_dict(test_score, self.app_paths.get_test_score_dict_path(output_directory))
         self.set_params(**prior_args)
-        return RunResult(validation_scores=eval_score, test_scores=test_score, model_path=model_path)
+        result = RunResult(validation_scores=eval_score, test_scores=test_score, model_path=model_path)
+        results_file_path = self.app_paths.get_run_results_path(output_directory)
+        with open(results_file_path, "wb") as fp:
+            pickle.dump(result, fp, pickle.HIGHEST_PROTOCOL)
+        return result
 
 
 if __name__ == "__main__":
